@@ -9,7 +9,7 @@
 
 int main(int argc, char** argv) {
     // decode MMTF file
-    std::string filename = "../mmtf_spec/test-suite/mmtf/173D.mmtf";
+    std::string filename = "../submodules/mmtf_spec/test-suite/mmtf/173D.mmtf";
     mmtf::StructureData data;
     read_check_file(data, filename);
 
